@@ -7,17 +7,14 @@ use ark_std::boxed::Box;
 pub(crate) use ark_std::vec::Vec;
 
 pub mod arbitrary;
-#[cfg(feature = "r1cs")]
-pub mod circuit;
+
 pub mod identity;
+pub mod keypair;
 pub mod leaf;
 pub mod merkle_tree;
 pub mod mimc;
 pub mod poseidon;
 pub mod set;
-#[cfg(feature = "r1cs")]
-pub mod setup;
-pub mod utils;
 
 pub type Error = Box<dyn ark_std::error::Error>;
 
